@@ -1,26 +1,26 @@
-from .api import Sqlite3
+from typing import Dict, Any
 
+from .api import Sqlite3
 
 # Постфиксы для выражения действий при вызове метода `filter`.
 # filter(table_name, filed_no=1, filed_2_egt=5)
 # Получится запрос “SELECT * FROM table_name WHERE filed != 0 AND field_2 >= 5”
 OPT_MAP = {
-    'gt': '>',
-    'lt': '<',
-    'no': '!=',
-    'egt': '>=',
-    'elt': '<=',
+    "gt": ">",
+    "lt": "<",
+    "no": "!=",
+    "egt": ">=",
+    "elt": "<=",
 }
 
 
 class Sqlite3ApiError(Exception):
     """
-    Ошибки, которые возникают при работе API
+    Ошибки, которые возникают при работе API.
     """
 
 
 class API(Sqlite3):
-
     def __init__(self, db_path: str = None):
         self._active = False
 
@@ -30,7 +30,7 @@ class API(Sqlite3):
 
     def save(self, *table_classes) -> str:
         """
-        Сохраняем все изменения.
+        Функция, сохраняющая все изменения.
         :param table_classes: Объекты классов таблиц.
         :type table_classes: Table.
         :return: "Successfully"
@@ -39,33 +39,37 @@ class API(Sqlite3):
         self._check_active()
 
         if len(table_classes) == 0:
-            raise Sqlite3ApiError('Не переданы классы таблиц')
+            raise Sqlite3ApiError("Не переданы классы таблиц.")
 
         for obj in table_classes:
             self.execute(
-                "UPDATE %s SET %s WHERE id=?" % (
+                "UPDATE %s SET %s WHERE id=?"
+                % (
                     obj.table_name,
-                    ', '.join(map(lambda x: f'{x}=?', obj.get_fields()))
+                    ", ".join(map(lambda x: f"{x}=?", obj.get_fields())),
                 ),
                 *map(
-                    lambda x: obj.__dict__[x], filter(
-                        lambda x: not x.startswith('_Table_') and x != 'id',
-                        vars(obj)
-                    )
-                ), obj.id
+                    lambda x: obj.__dict__[x],
+                    filter(
+                        lambda x: not x.startswith("_Table_") and x != "id", vars(obj)
+                    ),
+                ),
+                obj.id,
             )
         self.commit()
 
-        return 'Successfully'
+        return "Successfully"
 
     def filter(
-            self, table_name: str, table_fields: list = None,
-            **where
+        self,
+        table_name: str,
+        table_fields: Dict[str, str] = None,
+        **where: Dict[str, Any],
     ):
         """
-        Функция выбирает данные из таблицы на основе указанных параметров.
+        Функция, выбирающая данные из таблицы на основе указанных параметров.
         :param table_name: Название таблицы, с которой мы работаем.
-        :param table_fields:
+        :param table_fields: Поля, присутствующие в таблице, и их типы данных.
         :param where: Параметры сортировки.
         """
 
@@ -76,38 +80,34 @@ class API(Sqlite3):
         # Формирование параметров сортировки
         for key, value in where.items():
             field = key
-            opt = '='
-            if (index := key.rfind('_')) > 0:
+            opt = "="
+            if (index := key.rfind("_")) > 0:
                 try:
-                    opt = OPT_MAP[key[index + 1:]]
+                    opt = OPT_MAP[key[index + 1 :]]
                     field = key[:index]
                 except KeyError:
                     pass
 
             if table_fields and field not in table_fields:
                 raise Sqlite3ApiError(
-                    f'Поле `{field}` не найдено в таблице `{table_name}`'
+                    f"Поле `{field}` не найдено в таблице `{table_name}`"
                 )
 
-            conditions.append(f'{field} {opt} ?')
+            conditions.append(f"{field} {opt} ?")
             values.append(value)
 
         # Получение данных
         if conditions:
             return self.fetchall(
-                "SELECT * FROM '%s' WHERE %s" % (
-                    table_name,
-                    ' and '.join(conditions)),
-                *values
+                "SELECT * FROM '%s' WHERE %s" % (table_name, " and ".join(conditions)),
+                *values,
             )
         else:
-            return self.fetchall(
-                "SELECT * FROM '%s'" % table_name
-            )
+            return self.fetchall("SELECT * FROM '%s'" % table_name)
 
-    def insert(self, table_name: str, **fields) -> str:
+    def insert(self, table_name: str, **fields: Dict[str, Any]) -> str:
         """
-        Функция добавляет данные в таблицу.
+        Функция, добавляющая данные в таблицу.
         :param table_name: Название таблицы, с которой мы работаем.
         :param fields: {<название поля>: <значение>, ...}.
         :return: "Successfully"
@@ -116,23 +116,20 @@ class API(Sqlite3):
         self._check_active()
 
         self.execute(
-            "INSERT INTO %s (%s) VALUES (%s)" % (
-                table_name,
-                ', '.join(fields.keys()),
-                ', '.join(['?'] * len(fields))),
-            *fields.values()
+            "INSERT INTO %s (%s) VALUES (%s)"
+            % (table_name, ", ".join(fields.keys()), ", ".join(["?"] * len(fields))),
+            *fields.values(),
         )
 
         self.commit()
 
-        return 'Successfully'
+        return "Successfully"
 
     def add_field(
-            self, table_name: str,
-            field_name: str, field_type: str, start_value
+        self, table_name: str, field_name: str, field_type: str, start_value: Any
     ) -> str:
         """
-        Добавляет поле в таблицу.
+        Функция, добавляющая поле в таблицу.
         :param table_name: Название таблицы, с которой мы работаем.
         :param field_name: Название нового поля.
         :param field_type: Тип данных.
@@ -143,21 +140,18 @@ class API(Sqlite3):
         self._check_active()
 
         self.execute(
-            "ALTER TABLE '%s' ADD %s %s" % (
-                table_name, field_name, field_type)
+            "ALTER TABLE '%s' ADD %s %s" % (table_name, field_name, field_type)
         )  # Добавление нового поля
         self.execute(
-            "UPDATE '%s' SET %s=?" % (
-                table_name, field_name),
-            str(start_value)
+            "UPDATE '%s' SET %s=?" % (table_name, field_name), str(start_value)
         )  # Изменение стартового значения
         self.commit()
 
-        return 'Successfully'
+        return "Successfully"
 
-    def create_table(self, table_name, **fields) -> str:
+    def create_table(self, table_name: str, **fields: [str, str]) -> str:
         """
-        Создание таблицы.
+        Функция, создающая таблицу в базе данных.
         :param table_name: Название таблицы.
         :param fields: {<название поля>: <тип данных>, ...}
         :return: "Successfully"
@@ -166,23 +160,22 @@ class API(Sqlite3):
         self._check_active()
 
         fields = [
-            f'{key} {value}'
+            f"{key} {value}"
             for key, value in fields.items()
-            if key != 'id' and not key.startswith('__')
+            if key != "id" and not key.startswith("__")
         ]
 
         self.execute(
             "CREATE TABLE IF NOT EXISTS %s "
-            "(id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL, %s)" % (
-                table_name,
-                ', '.join(fields)
-            ))
+            "(id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL, %s)"
+            % (table_name, ", ".join(fields))
+        )
 
-        return 'Successfully'
+        return "Successfully"
 
     def _check_active(self):
         if not self._active:
-            raise Sqlite3ApiError('Файл базы данных не инициализирован')
+            raise Sqlite3ApiError("Файл базы данных не инициализирован.")
 
     @property
     def cursor(self):
@@ -190,14 +183,9 @@ class API(Sqlite3):
         Sqlite3 cursor.
         """
 
-    @cursor.getter
-    def cursor(self):
-        """
-        Получение курсора.
-        """
-
         self._check_active()
         return self._cursor
 
     def __del__(self):
-        self.close()
+        if self._active:
+            self.close()
